# Generated by Django 4.0.5 on 2022-06-27 18:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0047_historicalscreeningpartone_appt_datetime_repeat_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="appt_datetime_repeat",
            new_name="repeat_appt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="appt_datetime_repeat",
            new_name="repeat_appt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="appt_datetime_repeat",
            new_name="repeat_appt_datetime",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="appt_datetime_repeat",
            new_name="repeat_appt_datetime",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="appt_datetime_repeat",
            new_name="repeat_appt_datetime",
        ),
    ]



from .blood_results_fbc_admin import BloodResultsFbcAdmin
from .blood_results_hba1c_admin import BloodResultsHba1cAdmin
from .blood_results_ins_admin import BloodResultsInsAdmin
from .blood_results_lft_admin import BloodResultsLftAdmin
from .blood_results_lipids_admin import BloodResultsLipidsAdmin
from .blood_results_rft_admin import BloodResultsRftAdmin

__all__ = [
    "BloodResultsFbcAdmin",
    "BloodResultsHba1cAdmin",
    "BloodResultsInsAdmin",
    "BloodResultsLftAdmin",
    "BloodResultsLipidsAdmin",
    "BloodResultsRftAdmin",
]



from django.db import models
from edc_constants.choices import YES_NO
from edc_model.models import OtherCharField

from meta_lists.models import ArvRegimens, OiProphylaxis

from .arv_review_model_mixin import ArvReviewModelMixin


class ArvHistoryModelMixin(ArvReviewModelMixin, models.Model):
    hiv_diagnosis_date = models.DateField(
        verbose_name="When was the diagnosis of HIV made?", null=True, blank=True
    )

    arv_initiation_date = models.DateField(
        verbose_name="Date of start of antiretroviral therapy (ART)",
        null=True,
        blank=True,
    )

    has_previous_arv_regimen = models.CharField(
        verbose_name="Has the patient been on any previous regimen?",
        max_length=15,
        choices=YES_NO,
    )

    previous_arv_regimen = models.ForeignKey(
        ArvRegimens,
        on_delete=models.PROTECT,
        related_name="previous_arv_regimen",
        verbose_name="Which antiretroviral therapy regimen was the patient previously on?",
        null=True,
        blank=True,
    )

    other_previous_arv_regimen = OtherCharField(null=True, blank=True)

    on_oi_prophylaxis = models.CharField(
        verbose_name="Is the patient on any prophylaxis against opportunistic infections?",
        max_length=15,
        choices=YES_NO,
    )

    oi_prophylaxis = models.ManyToManyField(
        OiProphylaxis,
        verbose_name="If YES, which prophylaxis is the patient on?",
        blank=True,
    )

    other_oi_prophylaxis = OtherCharField(null=True, blank=True)

    class Meta:
        abstract = True



from django.db import models
from django_crypto_fields.fields import EncryptedTextField
from edc_adverse_event.models import CauseOfDeath
from edc_constants.choices import YES_NO
from edc_model_fields.fields import OtherCharField

from ..choices import DEATH_LOCATIONS, INFORMANT_RELATIONSHIP


class DeathReportModelMixin(models.Model):
    death_location = models.CharField(
        verbose_name="Where did the participant die?",
        max_length=50,
        choices=DEATH_LOCATIONS,
    )

    # TODO: if hospital of clinic, require, else NA
    hospital_name = models.CharField(
        verbose_name=(
            "If death occurred at hospital / clinic, please give name of the facility"
        ),
        max_length=150,
        default="",
        blank=True,
    )

    informant_contact = EncryptedTextField(null=True, blank=True)

    informant_relationship = models.CharField(
        max_length=50,
        choices=INFORMANT_RELATIONSHIP,
        verbose_name="Informants relationship to the participant?",
    )

    other_informant_relationship = OtherCharField()

    death_certificate = models.CharField(
        verbose_name="Is a death certificate is available?",
        max_length=15,
        choices=YES_NO,
    )

    secondary_cause_of_death = models.ForeignKey(
        CauseOfDeath,
        on_delete=models.PROTECT,
        related_name="secondary_cause_of_death",
        verbose_name="Secondary cause of death",
        help_text=(
            "Secondary cause of death in the opinion of the local study doctor and local PI"
        ),
    )

    secondary_cause_of_death_other = models.CharField(
        max_length=100,
        blank=True,
        default="",
        verbose_name='If "Other" above, please specify',
    )

    class Meta:
        abstract = True



# Generated by Django 5.0.1 on 2024-02-07 23:59
from uuid import uuid4

from django.db import migrations
from django.db.migrations import RunPython
from tqdm import tqdm


def update_duplicate_rx_identifier(apps, schema_editor):
    rx_model_cls = apps.get_model("edc_pharmacy.rx")
    qs = rx_model_cls.objects.filter(rx_identifier="0817ce95-fdc5-426b-9d4d-08fb717de2a6")
    for obj in tqdm(qs, total=qs.count()):
        obj.rx_identifier = uuid4()
        obj.save_base(update_fields="rx_identifier")
    rx_model_cls = apps.get_model("edc_pharmacy.historicalrx")
    qs = rx_model_cls.objects.filter(rx_identifier="0817ce95-fdc5-426b-9d4d-08fb717de2a6")
    for obj in tqdm(qs, total=qs.count()):
        obj.rx_identifier = uuid4()
        obj.save_base(update_fields="rx_identifier")


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_pharmacy",
            "0020_alter_box_device_created_alter_box_device_modified_and_more",
        )
    ]

    # ran this in shell manually 2024/02/13
    # operations = [RunPython(update_duplicate_rx_identifier)]
    operations = []



from django.contrib import admin
from edc_model_admin.dashboard import ModelAdminDashboardMixin
from edc_model_admin.mixins import TemplatesModelAdminMixin
from edc_qareports.modeladmin_mixins import QaReportModelAdminMixin
from edc_sites.admin import SiteModelAdminMixin
from edc_visit_schedule.admin import ScheduleStatusListFilter

from ...admin_site import meta_reports_admin
from ...models import UnattendedThreeInRow


@admin.register(UnattendedThreeInRow, site=meta_reports_admin)
class UnattendedThreeInRowAdmin(
    QaReportModelAdminMixin,
    SiteModelAdminMixin,
    ModelAdminDashboardMixin,
    TemplatesModelAdminMixin,
    admin.ModelAdmin,
):
    ordering = ("site", "subject_identifier")
    list_display = (
        "dashboard",
        "subject_identifier",
        "first_value",
        "second_value",
        "third_value",
        "interval_days",
        "from_now_days",
        "site",
        "created",
    )

    list_filter = (ScheduleStatusListFilter, "first_value", "second_value", "third_value")

    search_fields = ("subject_identifier", "first_value", "second_value", "third_value")



import pandas as pd
from edc_pdutils.dataframes import get_crf

from .utils import calculate_fasting_hrs

__all__ = ["get_glucose_fbg_ogtt_df"]


def get_glucose_fbg_ogtt_df(subject_identifiers: list[str] | None = None) -> pd.DataFrame:
    """Returns a prepared Dataframe of CRF meta_subject.glucose.

    Note: meta_subject.glucose has FBG and OGTT measures.
    """
    df = get_crf(
        model="meta_subject.glucose",
        subject_identifiers=subject_identifiers or [],
        subject_visit_model="meta_subject.subjectvisit",
    )
    df["source"] = "meta_subject.glucose"
    df = calculate_fasting_hrs(df)
    return df.reset_index(drop=True)



from django.db import models
from django_db_views.db_view import DBView
from edc_qareports.model_mixins import QaReportModelMixin, qa_reports_permissions

from .view_definition import get_view_definition


class MissingScreeningOgtt(QaReportModelMixin, DBView):
    screening_datetime = models.DateTimeField(null=True)

    fbg_datetime = models.DateTimeField(null=True)

    fbg_value = models.DecimalField(max_digits=8, decimal_places=2, null=True)

    ogtt_value = models.DecimalField(max_digits=8, decimal_places=2, null=True)

    fbg2_value = models.DecimalField(max_digits=8, decimal_places=2, null=True)

    ogtt2_value = models.DecimalField(max_digits=8, decimal_places=2, null=True)

    fbg2_datetime = models.DateTimeField(null=True)

    ogtt2_datetime = models.DateTimeField(null=True)

    repeated = models.CharField(
        default="", max_length=25, help_text="repeat_glucose_performed"
    )

    p3_ltfu = models.CharField(default="", max_length=25)

    consented = models.BooleanField(null=True)

    original_id = models.UUIDField(null=True)

    view_definition = get_view_definition()

    class Meta:
        managed = False
        db_table = "missing_screening_ogtt_view"
        verbose_name = "Screening: Missing OGTT"
        verbose_name_plural = "Screening: Missing OGTT"
        default_permissions = qa_reports_permissions



# Generated by Django 5.0.1 on 2024-02-13 04:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0170_remove_glucose_repeat_fbg_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("PENDING", "No. A repeat FBG will be scheduled"),
                    ("No", "No"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed",
                max_length=25,
                verbose_name="Has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If required, date particpant to repeat FBG",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("PENDING", "No. A repeat FBG will be scheduled"),
                    ("No", "No"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Response is applicable if reporting after 24/11/2023 and both the FBG and OGTT were performed",
                max_length=25,
                verbose_name="Has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If required, date particpant to repeat FBG",
            ),
        ),
    ]



from .dbviews import (
    NOTE_STATUSES,
    GlucoseSummary,
    ImpSubstitutions,
    MissingOgttNote,
    MissingScreeningOgtt,
    OnStudyMissingLabValues,
    OnStudyMissingValues,
    PatientHistoryMissingBaselineCd4,
    UnattendedThreeInRow,
    UnattendedThreeInRow2,
    UnattendedTwoInRow,
)
from .endpoints import Endpoints
from .endpoints_proxy import EndpointsProxy
from .last_imp_refill import LastImpRefill

__all__ = [
    "NOTE_STATUSES",
    "Endpoints",
    "EndpointsProxy",
    "GlucoseSummary",
    "ImpSubstitutions",
    "LastImpRefill",
    "MissingOgttNote",
    "MissingScreeningOgtt",
    "OnStudyMissingLabValues",
    "OnStudyMissingValues",
    "PatientHistoryMissingBaselineCd4",
    "UnattendedThreeInRow",
    "UnattendedThreeInRow2",
    "UnattendedTwoInRow",
]



# Generated by Django 5.1.5 on 2025-01-20 18:14

from django.core.exceptions import ObjectDoesNotExist
from django.db import IntegrityError, migrations, transaction
from edc_action_item.models import ActionItem
from edc_registration.models import RegisteredSubject
from tqdm import tqdm

from meta_consent.action_items import ConsentV1ExtensionAction


def update_missing_action_items(apps, schema_editor):
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(RegisteredSubject.objects.all(), total=total):
        try:
            ActionItem.objects.get(
                subject_identifier=obj.subject_identifier, action_type__name="consent_v1_ext"
            )
        except ObjectDoesNotExist:
            try:
                with transaction.atomic():
                    ConsentV1ExtensionAction(
                        subject_identifier=obj.subject_identifier,
                        skip_get_current_site=True,
                        site_id=obj.site_id,
                    )
            except IntegrityError:
                print(f"ERROR: Unable to create for {obj.subject_identifier}.")


class Migration(migrations.Migration):

    dependencies = [
        (
            "meta_consent",
            "0029_alter_historicalsubjectconsentv1ext_agrees_to_extension_and_more",
        ),
    ]

    operations = []



# Generated by Django 2.2.7 on 2020-01-20 17:20

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0002_auto_20191024_1000"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="other_offschedule_reason",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="other_offschedule_reason",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If OTHER, please specify",
            ),
        ),
    ]



from django.db import models
from django_db_views.db_view import DBView
from edc_qareports.model_mixins import QaReportModelMixin, qa_reports_permissions

from .view_definition import get_view_definition


class PatientHistoryMissingBaselineCd4(QaReportModelMixin, DBView):
    visit_code = models.CharField(max_length=25)

    visit_code_sequence = models.IntegerField()

    cd4 = models.IntegerField(verbose_name="Last CD4")

    cd4_date = models.DateField(verbose_name="Date of last CD4")

    user_created = models.CharField(max_length=25)

    user_modified = models.CharField(max_length=25)

    modified = models.DateTimeField()

    view_definition = get_view_definition()

    class Meta:
        managed = False
        db_table = "patient_history_missing_baseline_cd4_view"
        verbose_name = "Patient History: Missing Baseline Cd4"
        verbose_name_plural = "Missing Baseline Cd4"
        default_permissions = qa_reports_permissions



# Generated by Django 2.2.6 on 2019-11-07 19:49

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0006_auto_20191104_0756"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(55),
                ],
                verbose_name="ALT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(55),
                ],
                verbose_name="ALT",
            ),
        ),
    ]



from django.contrib import admin
from django.template.loader import render_to_string
from django.urls import reverse
from django.utils.translation import gettext as _
from edc_model_admin.dashboard import ModelAdminDashboardMixin
from edc_model_admin.mixins import TemplatesModelAdminMixin
from edc_qareports.modeladmin_mixins import (
    NoteStatusListFilter as BaseNoteStatusListFilter,
)
from edc_qareports.modeladmin_mixins import QaReportModelAdminMixin
from edc_sites.admin import SiteModelAdminMixin
from edc_visit_schedule.admin import ScheduleStatusListFilter

from ....admin_site import meta_reports_admin
from ....models import NOTE_STATUSES, MissingScreeningOgtt


class NoteStatusListFilter(BaseNoteStatusListFilter):
    note_model_status_choices = NOTE_STATUSES


@admin.register(MissingScreeningOgtt, site=meta_reports_admin)
class MissingScreeningOgttAdmin(
    QaReportModelAdminMixin,
    SiteModelAdminMixin,
    ModelAdminDashboardMixin,
    TemplatesModelAdminMixin,
    admin.ModelAdmin,
):
    note_model = "meta_reports.missingogttnote"
    note_status_list_filter = NoteStatusListFilter
    note_template = "edc_qareports/columns/notes_column.html"
    include_note_column = True

    ordering = ("site", "subject_identifier")

    list_display = (
        "dashboard",
        "subject_identifier",
        "site",
        "screening_date",
        "fbg_date",
        "fbg_value",
        "ogtt_value",
        "repeated",
        "p3_ltfu",
        "fbg2_value",
        "ogtt2_value",
        "fbg2_datetime",
        "ogtt2_datetime",
        "consented",
    )

    list_filter = (
        ScheduleStatusListFilter,
        "screening_datetime",
        "fbg_datetime",
        "repeated",
        "p3_ltfu",
    )

    search_fields = ("subject_identifier",)

    def dashboard(self, obj=None, label=None) -> str:
        url = self.get_subject_dashboard_url(obj=obj)
        if not url:
            url = reverse(
                "meta_screening_admin:meta_screening_subjectscreening_change",
                args=(obj.original_id,),
            )
        context = dict(title=_("Go to subject screening"), url=url, label=label)
        return render_to_string("edc_subject_dashboard/dashboard_button.html", context=context)

    @admin.display(description="Screen date", ordering="screening_datetime")
    def screening_date(self, obj):
        if obj.screening_datetime:
            return obj.screening_datetime.date()
        return None

    @admin.display(description="Fbg date", ordering="fbg_datetime")
    def fbg_date(self, obj):
        if obj.fbg_datetime:
            return obj.fbg_datetime.date()
        return None



# Generated by Django 2.2.6 on 2019-11-04 04:56

import django.core.validators
import django.db.models.deletion
import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0004_auto_20191102_1859"),
        ("meta_subject", "0005_auto_20191024_1000"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="hypertension",
            new_name="hypertension_diagnosis",
        ),
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="statins",
            new_name="taking_statins",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="hypertension",
            new_name="hypertension_diagnosis",
        ),
        migrations.RenameField(
            model_name="patienthistory", old_name="statins", new_name="taking_statins"
        ),
        migrations.RemoveField(
            model_name="historicalmedicationadherence", name="missed_pill_reason"
        ),
        migrations.RemoveField(
            model_name="historicalmedicationadherence", name="visual_score"
        ),
        migrations.RemoveField(model_name="historicalpatienthistory", name="family_diabetics"),
        migrations.RemoveField(
            model_name="historicalpatienthistory", name="hypertension_treatment"
        ),
        migrations.RemoveField(
            model_name="historicalpatienthistory", name="other_past_year_symptoms"
        ),
        migrations.RemoveField(
            model_name="historicalphysicalexam", name="has_abdominal_tenderness"
        ),
        migrations.RemoveField(model_name="historicalphysicalexam", name="has_enlarged_liver"),
        migrations.RemoveField(
            model_name="historicalphysicalexam", name="is_heartbeat_regular"
        ),
        migrations.RemoveField(model_name="medicationadherence", name="visual_score"),
        migrations.RemoveField(model_name="patienthistory", name="family_diabetics"),
        migrations.RemoveField(model_name="patienthistory", name="other_past_year_symptoms"),
        migrations.RemoveField(model_name="physicalexam", name="has_abdominal_tenderness"),
        migrations.RemoveField(model_name="physicalexam", name="has_enlarged_liver"),
        migrations.RemoveField(model_name="physicalexam", name="is_heartbeat_regular"),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="other_missed_pill_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                default=0,
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the score indicated from above.",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="visual_score_slider",
            field=models.CharField(
                default="0", help_text="%", max_length=3, verbose_name="Visual score"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="diabetes_in_family",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                help_text="Immediate family is parents, siblings, and children",
                max_length=15,
                verbose_name="Has anyone in your immediate family ever been diagnosed with diabetes?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="other_diabetes_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other symptom in the <u>past year</u>, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="other_hypertension_treatment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other medication(s), please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="abdominal_tenderness_description",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If YES, abdominal tenderness, please describe",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="enlarged_liver",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Enlarged liver on palpation?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="irregular_heartbeat_description",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If the heartbeat is <u>irregular</u>, please describe",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="other_missed_pill_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="visual_score_confirmed",
            field=models.IntegerField(
                default=0,
                help_text="%",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the score indicated from above.",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="visual_score_slider",
            field=models.CharField(
                default="0", help_text="%", max_length=3, verbose_name="Visual score"
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="diabetes_in_family",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                help_text="Immediate family is parents, siblings, and children",
                max_length=15,
                verbose_name="Has anyone in your immediate family ever been diagnosed with diabetes?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="other_diabetes_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other symptom in the <u>past year</u>, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="other_hypertension_treatment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other medication(s), please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="abdominal_tenderness_description",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If YES, abdominal tenderness, please describe",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="enlarged_liver",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Enlarged liver on palpation?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="irregular_heartbeat_description",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If the heartbeat is <u>irregular</u>, please describe",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="art_new_regimen_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowup",
            name="art_new_regimen_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="current_smoker",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the patient a <u>current</u> smoker?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="former_smoker",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the patient a <u>previous</u> smoker?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_current_arv_regimen",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_oi_prophylaxis",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_previous_arv_regimen",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="abdominal_tenderness",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Abdominal tenderness on palpation?",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="irregular_heartbeat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Is the heart beat <u>irregular</u>?",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="jaundice",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Jaundice?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="peripheral_oedema",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Presence of peripheral oedema?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="reason_not_drawn_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.RemoveField(model_name="medicationadherence", name="missed_pill_reason"),
        migrations.AddField(
            model_name="medicationadherence",
            name="missed_pill_reason",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.NonAdherenceReasons",
                verbose_name="Reasons for missing study pills",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="current_smoker",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the patient a <u>current</u> smoker?",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="diabetes_symptoms",
            field=models.ManyToManyField(
                to="meta_lists.DiabetesSymptoms",
                verbose_name="In the <u>past year</u>, have you had any of the following symptoms?",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="former_smoker",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Is the patient a <u>previous</u> smoker?",
            ),
        ),
        migrations.RemoveField(model_name="patienthistory", name="hypertension_treatment"),
        migrations.AddField(
            model_name="patienthistory",
            name="hypertension_treatment",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.HypertensionMedications",
                verbose_name="What medications is the patient currently taking for hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="other_current_arv_regimen",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="other_oi_prophylaxis",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="other_previous_arv_regimen",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="other_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="previous_arv_regimen",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="previous_arv_regimen",
                to="meta_lists.ArvRegimens",
                verbose_name="Which antiretroviral therapy regimen was the patient previously on?",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="abdominal_tenderness",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Abdominal tenderness on palpation?",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="irregular_heartbeat",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="?",
                max_length=15,
                verbose_name="Is the heart beat <u>irregular</u>?",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="jaundice",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Jaundice?",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="peripheral_oedema",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Presence of peripheral oedema?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrequisition",
            name="reason_not_drawn_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]



# Generated by Django 3.2.4 on 2021-07-09 19:41

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0059_auto_20210709_2056"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultslft",
            name="amylase_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="amylase_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=6,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999),
                ],
                verbose_name="Serum Amylase",
            ),
        ),
    ]



from django import forms

from ..models import Rx


class RxForm(forms.ModelForm):
    subject_identifier = forms.CharField(
        label="Subject Identifier",
        required=False,
        widget=forms.TextInput(attrs={"readonly": "readonly"}),
    )

    class Meta:
        model = Rx
        fields = "__all__"



# Generated by Django 4.0.5 on 2022-06-25 18:56

import django.db.models.deletion
import edc_model.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_protocol_incident",
            "0005_protocolincident_historicalprotocolincident_and_more",
        ),
        ("meta_prn", "0025_alter_historicalprotocoldeviationviolation_options_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalprotocoldeviationviolation",
            name="violation_type",
        ),
        migrations.RemoveField(
            model_name="historicalprotocoldeviationviolation",
            name="violation_type_other",
        ),
        migrations.RemoveField(
            model_name="protocoldeviationviolation",
            name="violation_type",
        ),
        migrations.RemoveField(
            model_name="protocoldeviationviolation",
            name="violation_type_other",
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="incident",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_protocol_incident.protocolviolations",
                verbose_name="Type of incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="incident_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Date incident occurred",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="incident_description",
            field=models.TextField(
                help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                null=True,
                verbose_name="Describe the incident",
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="incident_reason",
            field=models.TextField(
                null=True, verbose_name="Explain the reason why the incident occurred"
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="incident",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_protocol_incident.protocolviolations",
                verbose_name="Type of incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="incident_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Date incident occurred",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="incident_description",
            field=models.TextField(
                help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                null=True,
                verbose_name="Describe the incident",
            ),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="incident_reason",
            field=models.TextField(
                null=True, verbose_name="Explain the reason why the incident occurred"
            ),
        ),
    ]



# Generated by Django 5.0.8 on 2024-08-23 15:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0037_historicalmissingogttnote_result_status_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmissingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Did the participant fast?",
            ),
        ),
        migrations.AlterField(
            model_name="missingogttnote",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Did the participant fast?",
            ),
        ),
    ]



# Generated by Django 6.0 on 2025-04-02 16:13
from django.apps import apps as django_apps
from django.db import migrations
from django.db.migrations import RunPython
from edc_appointment.constants import MISSED_APPT
from edc_pdutils.dataframes import get_crf
from edc_utils import get_utcnow
from tqdm import tqdm


def update(apps, schema_editor):
    """Correct missed appointments incorrectly set to
    appt_timing=ONTIME_APPT.
    """
    appointment_model_cls = django_apps.get_model("edc_appointment.appointment")
    df_missedvisit = get_crf(
        "meta_subject.subjectvisitmissed",
        subject_visit_model="meta_subject.subjectvisit",
    )
    df_subjects = df_missedvisit[df_missedvisit.appt_timing != MISSED_APPT][
        ["subject_identifier", "visit_code_str", "visit_code_sequence"]
    ].copy()
    for tpl in tqdm(df_subjects.itertuples(), total=len(df_subjects)):
        obj = appointment_model_cls.objects.get(
            subject_identifier=tpl.subject_identifier,
            visit_code=tpl.visit_code_str,
            visit_code_sequence=tpl.visit_code_sequence,
        )
        obj.appt_timing = MISSED_APPT
        obj.modified = get_utcnow()
        obj.user_modified = "erikvw"

        obj.save(update_fields=["appt_timing", "user_modified", "modified"])


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0220_historicalbloodresultsgludummy_bloodresultsgludummy"),
    ]

    operations = [RunPython(update)]



from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_mnsi.admin_site import edc_mnsi_admin
from edc_mnsi.fieldsets import calculated_values_fieldset
from edc_mnsi.fieldsets import get_fieldsets as get_mnsi_fieldsets
from edc_mnsi.model_admin_mixin import MnsiModelAdminMixin, radio_fields
from edc_mnsi.models import Mnsi as DefaultMnsi
from edc_model_admin.history import SimpleHistoryAdmin

from meta_subject.admin_site import meta_subject_admin

from ..forms import MnsiForm
from ..models import Mnsi
from .modeladmin import CrfModelAdminMixin


def get_fieldsets():
    fieldset = (
        None,
        {
            "fields": (
                "subject_visit",
                "report_datetime",
                "mnsi_performed",
                "mnsi_not_performed_reason",
            )
        },
    )

    return (
        fieldset,
        *get_mnsi_fieldsets(),
        crf_status_fieldset_tuple,
        calculated_values_fieldset,
        audit_fieldset_tuple,
    )


edc_mnsi_admin.unregister(DefaultMnsi)
radio_fields.update(crf_status=admin.VERTICAL)


@admin.register(Mnsi, site=meta_subject_admin)
class MnsiAdmin(
    MnsiModelAdminMixin,
    CrfModelAdminMixin,
    SimpleHistoryAdmin,
):
    form = MnsiForm

    fieldsets = get_fieldsets()

    radio_fields = radio_fields



from django.db import models
from edc_constants.choices import MARITAL_STATUS
from edc_he.model_mixins import EducationModelMixin
from edc_model.models import BaseUuidModel

from ...model_mixins import CrfModelMixin


class HealthEconomicsSimple(EducationModelMixin, CrfModelMixin, BaseUuidModel):
    occupation = models.CharField(
        verbose_name="What is your occupation/profession?", max_length=50
    )

    marital_status = models.CharField(
        verbose_name="Marital status",
        max_length=25,
        choices=MARITAL_STATUS,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Health Economics (M3)"
        verbose_name_plural = "Health Economics (M3)"



from edc_list_data.model_mixins import ListModelMixin


class AbnormalFootAppearanceObservations(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Abnormal Foot Appearance Observations"
        verbose_name_plural = "Abnormal Foot Appearance Observations"


class Symptoms(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Symptoms"
        verbose_name_plural = "Symptoms"


class ArvRegimens(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "ARV Regimens"
        verbose_name_plural = "ARV Regimens"


class OffstudyReasons(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Offstudy Reasons"
        verbose_name_plural = "Offstudy Reasons"


class OiProphylaxis(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "OI Prophylaxis"
        verbose_name_plural = "OI Prophylaxis"


class BaselineSymptoms(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Baseline Symptoms"
        verbose_name_plural = "Baseline Symptoms"


class DiabetesSymptoms(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Diabetes Symptoms"
        verbose_name_plural = "Diabetes Symptoms"


class HypertensionMedications(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Hypertension Medications"
        verbose_name_plural = "Hypertension Medications"


class NonAdherenceReasons(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Non-Adherence Reasons"
        verbose_name_plural = "Non-Adherence Reasons"


class SubjectVisitMissedReasons(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Subject Missed Visit Reasons"
        verbose_name_plural = "Subject Missed Visit Reasons"


class TransferReasons(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Transfer Reasons"
        verbose_name_plural = "Transfer Reasons"


class HealthcareWorkers(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Healthcare worker"
        verbose_name_plural = "Healthcare workers"


class Investigations(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Investigations"
        verbose_name_plural = "Investigations"


class Complications(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Complications"
        verbose_name_plural = "Complications"


class DmTreatments(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "DmTreatments"
        verbose_name_plural = "DmTreatments"


class DmMedications(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Diabetes Medications"
        verbose_name_plural = "Diabetes Medications"


class MissedReferralReasons(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Missed Referral Reasons"
        verbose_name_plural = "Missed Referral Reasons"


class DiagnosticDevices(ListModelMixin):
    class Meta(ListModelMixin.Meta):
        verbose_name = "Diagnostic device"
        verbose_name_plural = "Diagnostic devices"



# Generated by Django 3.2.11 on 2022-03-04 02:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0095_auto_20220128_1719"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> FBG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="FBG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="FBG units",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="FBG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_datetime",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="<u>Time</u> FBG level measured"
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_quantifier",
            field=models.CharField(
                choices=[
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="=",
                max_length=10,
                verbose_name="FBG quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_units",
            field=models.CharField(
                choices=[
                    ("mg/dL", "mg/dL"),
                    ("mmol/L", "mmol/L (millimoles/L)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="FBG units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="FBG level",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-29 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0067_alter_offschedule_managers_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmreferral",
            name="referral_note",
            field=models.TextField(
                default="",
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="other_offstudy_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferral",
            name="referral_note",
            field=models.TextField(
                default="",
                verbose_name="Please provide a brief history of the diabetes diagnosis that lead to this referral",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_investigator_decision",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawl was an 'investigator decision', please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If withdrawn for 'other' condition, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="Please provide further details if possible",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="other_offstudy_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="toxicity_withdrawal_reason_other",
            field=models.TextField(
                blank=True,
                default="",
                max_length=500,
                verbose_name="If 'other toxicity', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="comment",
            field=models.TextField(
                default="",
                verbose_name="Please give details of the circumstances that have led to this decision.",
            ),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="home_visit_detail",
            field=models.TextField(
                default="",
                verbose_name="If YES, provide any further details of the home visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, default="", verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancynotification",
            name="unconfirmed_details",
            field=models.TextField(
                blank=True, default="", verbose_name="If no, please provide details"
            ),
        ),
        migrations.AlterField(
            model_name="historicalprotocolincident",
            name="action_required_old",
            field=models.CharField(
                choices=[
                    ("remain_on_study", "Participant to remain on trial"),
                    ("to_be_withdrawn", "Participant to be withdrawn from trial"),
                    (
                        "remain_on_study_modified",
                        "Patient remains on study but data analysis will be modified",
                    ),
                ],
                default="",
                max_length=45,
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="comment",
            field=models.TextField(
                default="",
                verbose_name="Please give details of the circumstances that have led to this decision.",
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="home_visit_detail",
            field=models.TextField(
                default="",
                verbose_name="If YES, provide any further details of the home visit",
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, default="", verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="pregnancynotification",
            name="unconfirmed_details",
            field=models.TextField(
                blank=True, default="", verbose_name="If no, please provide details"
            ),
        ),
        migrations.AlterField(
            model_name="protocolincident",
            name="action_required_old",
            field=models.CharField(
                choices=[
                    ("remain_on_study", "Participant to remain on trial"),
                    ("to_be_withdrawn", "Participant to be withdrawn from trial"),
                    (
                        "remain_on_study_modified",
                        "Patient remains on study but data analysis will be modified",
                    ),
                ],
                default="",
                max_length=45,
            ),
        ),
    ]



# Generated by Django 4.2.1 on 2023-06-07 14:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0159_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="education_certificate",
            field=models.CharField(
                choices=[
                    ("primary", "Primary Certificate"),
                    ("secondary", "Secondary Certificate"),
                    ("tertiary", "post-Secondary/Tertiary/College"),
                    ("OTHER", "Other, specify ..."),
                    ("N/A", "Not applicable, never went to school"),
                ],
                max_length=50,
                null=True,
                verbose_name="What is your highest education certificate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicssimple",
            name="education_certificate",
            field=models.CharField(
                choices=[
                    ("primary", "Primary Certificate"),
                    ("secondary", "Secondary Certificate"),
                    ("tertiary", "post-Secondary/Tertiary/College"),
                    ("OTHER", "Other, specify ..."),
                    ("N/A", "Not applicable, never went to school"),
                ],
                max_length=50,
                null=True,
                verbose_name="What is your highest education certificate?",
            ),
        ),
    ]



import sys

from django.conf import settings
from django.core.management.base import BaseCommand
from django.core.management.color import color_style
from edc_form_describer.forms_reference import FormsReference

from meta_subject.admin_site import meta_subject_admin
from meta_visit_schedule.visit_schedules import visit_schedule

style = color_style()


def update_forms_reference(sender=None, **kwargs):  # noqa: ARG001
    sys.stdout.write(
        style.MIGRATE_HEADING("Refreshing CRF reference document for meta_subject\n")
    )
    doc_folder = settings.BASE_DIR / "docs"
    if not doc_folder.exists():
        doc_folder.mkdir()
    forms = FormsReference(
        visit_schedules=[visit_schedule],
        admin_site=meta_subject_admin,
        add_per_form_timestamp=False,
    )
    path = doc_folder / "forms_reference.md"
    forms.to_file(path=path, overwrite=True, pad=0)


class Command(BaseCommand):
    help = "Update forms reference document (.md)"

    def handle(self, *args, **options):  # noqa: ARG002
        update_forms_reference()



from django import forms
from django.forms import ALL_FIELDS
from edc_adverse_event.modelform_mixins import HospitalizationModelFormMixin

from ..models import Hospitalization


class HospitalizationForm(HospitalizationModelFormMixin, forms.ModelForm):
    class Meta(HospitalizationModelFormMixin.Meta):
        model = Hospitalization
        fields = ALL_FIELDS



# Generated by Django 5.1.2 on 2025-01-15 23:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0018_missedreferralreasons"),
        ("meta_prn", "0061_auto_20250115_2025"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="offstudy_reason",
            field=models.ForeignKey(
                limit_choices_to={
                    "name__in": [
                        "completed_followup",
                        "completed_followup_48",
                        "diabetes",
                        "delivery",
                        "pregnancy",
                        "clinical_withdrawal",
                        "dead",
                        "LTFU",
                        "toxicity",
                        "transferred",
                        "withdrawal",
                        "late_exclusion",
                        "OTHER",
                    ]
                },
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="meta_lists.offstudyreasons",
                verbose_name="Reason patient was terminated from the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="offstudy_reason",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={
                    "name__in": [
                        "completed_followup",
                        "completed_followup_48",
                        "diabetes",
                        "delivery",
                        "pregnancy",
                        "clinical_withdrawal",
                        "dead",
                        "LTFU",
                        "toxicity",
                        "transferred",
                        "withdrawal",
                        "late_exclusion",
                        "OTHER",
                    ]
                },
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.offstudyreasons",
                verbose_name="Reason patient was terminated from the study",
            ),
        ),
    ]



from clinicedc_constants import NOT_EVALUATED
from django.db import models
from django_db_views.db_view import DBView
from edc_constants.choices import YES_NO_NOT_EVALUATED
from edc_qareports.model_mixins import QaReportModelMixin, qa_reports_permissions

from .view_definition import get_view_definition


class ImpSubstitutions(QaReportModelMixin, DBView):
    original_id = models.UUIDField(null=True)

    sid = models.IntegerField(verbose_name="Original SID", null=True)

    dispensed_sid = models.IntegerField(verbose_name="Dispensed SID", null=True)

    arm_match = models.CharField(
        max_length=15,
        choices=YES_NO_NOT_EVALUATED,
        default=NOT_EVALUATED,
    )

    report_datetime = models.DateTimeField(null=True)

    allocated_datetime = models.DateTimeField(null=True)

    user_created = models.CharField(max_length=25)

    user_modified = models.CharField(max_length=25)

    modified = models.DateTimeField(null=True)

    view_definition = get_view_definition()

    class Meta:
        managed = False
        db_table = "imp_subjectitutions_view"
        verbose_name = "IMP Substitutions"
        verbose_name_plural = "IMP Substitutions"
        default_permissions = qa_reports_permissions



from .ae_followup_admin import AeFollowupAdmin
from .ae_initial_admin import AeInitialAdmin
from .ae_susar_admin import AeSusarAdmin
from .ae_tmg_admin import AeTmgAdmin
from .death_report_admin import DeathReportAdmin
from .death_report_tmg_admin import DeathReportTmgAdmin
from .death_report_tmg_second_admin import DeathReportTmgSecondAdmin
from .hospitalization_admin import HospitalizationAdmin

__all__ = [
    "AeFollowupAdmin",
    "AeInitialAdmin",
    "AeSusarAdmin",
    "AeTmgAdmin",
    "DeathReportAdmin",
    "DeathReportTmgAdmin",
    "DeathReportTmgSecondAdmin",
    "HospitalizationAdmin",
]



from .arv_history_model_mixin import ArvHistoryModelMixin
from .arv_review_model_mixin import ArvReviewModelMixin
from .crf_model_mixin import CrfModelMixin
from .crf_with_action_model_mixin import CrfWithActionModelMixin
from .search_slug_model_mixin import SearchSlugModelMixin
from .vitals_fields_model_mixin import VitalsFieldsModelMixin

__all__ = [
    "ArvHistoryModelMixin",
    "ArvReviewModelMixin",
    "CrfModelMixin",
    "CrfWithActionModelMixin",
    "SearchSlugModelMixin",
    "VitalsFieldsModelMixin",
]



from django.contrib import admin
from edc_adherence.model_admin_mixin import MedicationAdherenceAdminMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import meta_subject_admin
from ..forms import MedicationAdherenceForm
from ..models import MedicationAdherence
from .modeladmin import CrfModelAdminMixin


@admin.register(MedicationAdherence, site=meta_subject_admin)
class MedicationAdherenceAdmin(
    MedicationAdherenceAdminMixin, CrfModelAdminMixin, SimpleHistoryAdmin
):
    form = MedicationAdherenceForm



from django import forms
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_lab_panel.panels import hba1c_panel, hba1c_poc_panel
from edc_lab_results.form_validator_mixins import BloodResultsFormValidatorMixin

from ...models import BloodResultsHba1c


class BloodResultsHba1cFormValidator(BloodResultsFormValidatorMixin, CrfFormValidator):
    panels = (hba1c_poc_panel, hba1c_panel)


class BloodResultsHba1cForm(ActionItemCrfFormMixin, CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = BloodResultsHba1cFormValidator

    class Meta(ActionItemCrfFormMixin.Meta):
        model = BloodResultsHba1c
        fields = "__all__"



# Generated by Django 3.2.11 on 2022-07-19 18:42

from django.db import migrations


def update_egfr_drop_action(apps, schema_editor):
    # action_item_model_cls = apps.get_model("edc_action_item.actionitem")
    crf_metadata_model_cls = apps.get_model("edc_metadata.crfmetadata")
    # action_item_model_cls.objects.filter(
    #     reference_model="meta_subject.egfrnotification"
    # ).update(reference_model="meta_subject.egfrdropnotification")
    crf_metadata_model_cls.objects.filter(model="meta_subject.egfrnotification").update(
        model="meta_subject.egfrdropnotification"
    )


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0125_auto_20220719_2134"),
    ]

    operations = [migrations.RunPython(update_egfr_drop_action)]



# Generated by Django 4.2.11 on 2024-05-15 23:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0195_alter_glucosefbg_fbg_datetime_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="glucosefbg",
            name="fbg_not_performed_reason",
            field=models.CharField(
                blank=True, max_length=150, null=True, verbose_name="If NO, provide reason"
            ),
        ),
        migrations.AddField(
            model_name="glucosefbg",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalglucosefbg",
            name="fbg_not_performed_reason",
            field=models.CharField(
                blank=True, max_length=150, null=True, verbose_name="If NO, provide reason"
            ),
        ),
        migrations.AddField(
            model_name="historicalglucosefbg",
            name="fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Was the FBG test performed?",
            ),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.4 on 2021-06-23 23:25

import django.db.models.deletion
import edc_model.models.fields.initials_field
import edc_model.models.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_action_item", "0028_auto_20210203_0706"),
        ("meta_subject", "0051_auto_20200617_2117"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalpatienthistory",
            old_name="hypertension_diagnosis",
            new_name="htn_diagnosis",
        ),
        migrations.RenameField(
            model_name="patienthistory",
            old_name="hypertension_diagnosis",
            new_name="htn_diagnosis",
        ),
        migrations.AddField(
            model_name="complications",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="complications",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="followupexamination",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="followupexamination",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="followupvitals",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="followupvitals",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomics",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomics",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplications",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplications",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupexamination",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupexamination",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupvitals",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupvitals",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomics",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomics",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalmalariatest",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalmalariatest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="If 'Yes', complete the Loss to Follow up form",
                max_length=15,
                verbose_name="Has the participant met the protocol criteria for lost to follow up?",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinedipsticktest",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinedipsticktest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="malariatest",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="malariatest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="No",
                help_text="If 'Yes', complete the Loss to Follow up form",
                max_length=15,
                verbose_name="Has the participant met the protocol criteria for lost to follow up?",
            ),
        ),
        migrations.AddField(
            model_name="urinedipsticktest",
            name="crf_status",
            field=models.CharField(
                choices=[
                    ("INCOMPLETE", "Incomplete (some data pending)"),
                    ("COMPLETE", "Complete"),
                ],
                default="COMPLETE",
                help_text="If some data is still pending, flag this CRF as incomplete",
                max_length=25,
                verbose_name="CRF status",
            ),
        ),
        migrations.AddField(
            model_name="urinedipsticktest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                help_text="for example, why some data is still pending",
                null=True,
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="pill_count",
            field=models.IntegerField(
                null=True, verbose_name="Number of pills left in the bottle"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="clinician_initials",
            field=edc_model.models.fields.initials_field.InitialsField(
                blank=True,
                help_text="Type 2-3 letters, all in uppercase and no spaces",
                max_length=3,
                null=True,
                verbose_name="Initials",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="reason_not_drawn_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                help_text="If deceased, complete the death report",
                max_length=25,
                verbose_name="Survival status",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="pill_count",
            field=models.IntegerField(
                null=True, verbose_name="Number of pills left in the bottle"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrequisition",
            name="clinician_initials",
            field=edc_model.models.fields.initials_field.InitialsField(
                blank=True,
                help_text="Type 2-3 letters, all in uppercase and no spaces",
                max_length=3,
                null=True,
                verbose_name="Initials",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrequisition",
            name="reason_not_drawn_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                help_text="If deceased, complete the death report",
                max_length=25,
                verbose_name="Survival status",
            ),
        ),
    ]



import sys

from django.core.management import BaseCommand

from meta_pharmacy.utils import update_initial_pharmacy_data


class Command(BaseCommand):
    def handle(self, *args, **options):  # noqa: ARG002
        update_initial_pharmacy_data()
        sys.stdout.write("Done\n")



# Generated by Django 5.0.1 on 2024-02-13 03:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0017_complications_dmmedications_dmtreatments_and_more"),
        ("meta_subject", "0168_alter_dmreferralfollowup_last_missed_pill_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dmreferralfollowup",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "verbose_name": "Diabetes referral follow-up",
                "verbose_name_plural": "Diabetes referral follow-up",
            },
        ),
        migrations.AddField(
            model_name="glucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Answer yes or no if both the FBG and OGTT are available",
                max_length=25,
                verbose_name="Based on the tests results above, has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="repeat_fbg",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="FBG needs to be repeated if the above FBG>=7 and OGTT<11.1",
                max_length=25,
                verbose_name="As per protocol, does the FBG need to be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="Date particpant to repeat FBG"
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="endpoint_today",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Answer yes or no if both the FBG and OGTT are available",
                max_length=25,
                verbose_name="Based on the tests results above, has the participant reached a study endpoint today?",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="repeat_fbg",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="FBG needs to be repeated if the above FBG>=7 and OGTT<11.1",
                max_length=25,
                verbose_name="As per protocol, does the FBG need to be repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="repeat_fbg_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="Date particpant to repeat FBG"
            ),
        ),
        migrations.AddIndex(
            model_name="dmreferralfollowup",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_cfb7da_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmreferralfollowup",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="meta_subjec_subject_257846_idx",
            ),
        ),
    ]



from .ae_followup_form import AeFollowupForm
from .ae_initial_form import AeInitialForm
from .ae_local_review_form import AeLocalReviewForm
from .ae_sponsor_review_form import AeSponsorReviewForm
from .ae_susar_form import AeSusarForm
from .ae_tmg_form import AeTmgForm
from .death_report_form import DeathReportForm
from .death_report_tmg_form import DeathReportTmgForm
from .death_report_tmg_second_form import DeathReportTmgSecondForm
from .hospitalization_form import HospitalizationForm

__all__ = [
    "AeFollowupForm",
    "AeInitialForm",
    "AeLocalReviewForm",
    "AeSponsorReviewForm",
    "AeSusarForm",
    "AeTmgForm",
    "DeathReportForm",
    "DeathReportTmgForm",
    "DeathReportTmgSecondForm",
    "HospitalizationForm",
]



from django import forms
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..models import ComplicationsGlycemia


class ComplicationsGlycemiaForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = CrfFormValidator

    class Meta:
        model = ComplicationsGlycemia
        fields = "__all__"
